#
# spec file for package python3-rpc4django
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.
#
# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           python3-rpc4django
Version:        0.3.0
Release:        2.3
Url:            https://github.com/davidfischer/rpc4django
Summary:        Handles JSONRPC and XMLRPC requests easily with Django
License:        BSD-2-Clause
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/r/rpc4django/rpc4django-%{version}.tar.gz
BuildRequires:  python3-devel
Requires:       python3-django
BuildArch:      noarch

%description
RPC4Django is an XMLRPC and JSONRPC server for Django powered projects.
Simply plug it into any existing Django project and you can make your
methods available via XMLRPC and JSONRPC. In addition, it can display nice
documentation about the methods it makes available in a more customizable
way than DocXMLRPCServer_.

RPC4Django is not affiliated with the `Django Project`_.

.. _DocXMLRPCServer: http://docs.python.org/library/docxmlrpcserver.html
.. _Django Project: http://djangoproject.com

Features
--------

- Detects request type (JSONRPC or XMLRPC) based on content
- Easy identification of RPC methods via a decorator
- Pure python and requires no external modules except Django
- Customizable RPC method documentation including reST_
- Supports XMLRPC and JSONRPC introspection
- Supports method signatures (unlike SimpleXMLRPCServer)
- Easy installation and integration with existing Django projects
- Licensed for inclusion in open source and commercial software
- Ties in with Django's `authentication and authorization`_

.. _reST: http://docutils.sourceforge.net/rst.html
.. _authentication and authorization: http://docs.djangoproject.com/en/dev/topics/auth

%prep
%setup -q -n rpc4django-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc docs/_build/html/_sources/* README.rst LICENSE.rst
%{python3_sitelib}/*

%changelog
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Sat Jan 10 2015 arun@gmx.de
- specfile:
  * update copyright year
  * remove trailing whitespace
  * update url
- update to version 0.3.0:
  * Use the defusedxml library for XML parsing and XMLRPC which solves
    issues with entity expansion. Thanks to Dan Burrowes for reporting
    the issues.
  * Fix a bug involving unicode literals causing TypeErrors (#31)
- changes from version 0.2.5:
  * Django 1.6 compatibility (#29)
* Fri Oct 11 2013 p.drouand@gmail.com
- Initial python3 support
* Fri Oct 11 2013 p.drouand@gmail.com
- Update to version 0.2.4
  + fixed a packaging issue with 0.2.3
- Changes between 0.2.3 and 0.2.2
  + Python3 compatibility
  + Code cleanup and code quality
  + fixed billion laughs denial of service issue
    claused https://github.com/davidfischer/rpc4django/issues/20
- Changes between 0.2.2 and 0.2.1
  + fixed error involving simplejson with Django 1.5
    claused https://github.com/davidfischer/rpc4django/issues/14
  + fixed ProtocolError relating to modwsgi and JSONEncoder
    claused https://github.com/davidfischer/rpc4django/issues/15
  + formatting cleanup
- Use download url as source
- Add documentation from tarball
* Fri Mar  8 2013 alexandre@exatati.com.br
- Update to 0.2.1:
  - Body length check fix for Django 1.5.
* Mon Nov  5 2012 alexandre@exatati.com.br
- Update to 0.2.0:
  - The demo site is now on Heroku
  - params is now optional in JSONRPC requests (thanks to
    Albert Hopkins)
  - Switching supported versions to Django supported versions
    (deprecating Django < 1.3 support)
  - Moved documentation to readthedocs.org
* Fri Feb  3 2012 alexandre@exatati.com.br
- Update to 0.1.12:
  - JSON encoding is customizable (thanks to Alexander Morozov)
* Thu Dec 22 2011 alexandre@exatati.com.br
- Update to 0.1.11:
  - Added a login_required parameter to the @rpcmethod decorator.
* Tue Nov 15 2011 alexandre@exatati.com.br
- Update to 0.1.10:
  - Removed requirement on Django in setup.py #798823
  - Refactored to use standard setuptools tests (python setup.py test)
  - Moved development to Github
* Mon Jul 11 2011 alexandre@exatati.com.br
- Update to 0.1.9:
  - Added a CookieTransport class with a lot of help from Douglas Peter Sculley.
  - RPC4Django's logging now goes to the rpc4django logger.
  - Catches an ExpatError in xmlrpclib that was previously uncaught under
    certain conditions
  - Fixed error with scanning of INSTALLED_APPS for @rpcmethods. This
    was causing an issue when South was installed. #807628
  - Fixed bug #807653 related to scanning ServerProxy objects
- Regenerate spec file with py2pack.
* Wed Oct 27 2010 alexandre@exatati.com.br
- Update to 0.1.8;
- Bzip2 source file;
- Spec file cleaned with spec-cleaner.
* Tue Jan 19 2010 alexandre@exatati.com.br
- Update to 0.1.7;
- Added pyxml as BuildRequires.
* Thu Jan 14 2010 alexandre@exatati.com.br
- Update to 0.1.6.
* Mon Oct  5 2009 alexandre@exatati.com.br
- Update to 0.1.5;
- Building as noarch for openSUSE >= 11.2.
* Tue Sep  1 2009 alexandre@exatati.com.br
- Initial package (0.1.4) for openSUSE.
